## Classes


```{eval-rst}
.. currentmodule:: scanpy
```

{class}`~anndata.AnnData` is reexported from {mod}`anndata`.

Represent data as a neighborhood structure, usually a knn graph.

```{eval-rst}
.. autosummary::
   :nosignatures:
   :toctree: ../generated/

   Neighbors

```
